<?php

namespace Drupal\friendlycaptcha\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Friendly Captcha settings for this site.
 */
class FriendlyCaptchaAdminSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'friendlycaptcha_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['friendlycaptcha.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('friendlycaptcha.settings');

    $form['general'] = [
      '#type' => 'details',
      '#title' => $this->t('General settings'),
      '#open' => TRUE,
    ];

    $form['general']['friendlycaptcha_site_key'] = [
      '#default_value' => $config->get('site_key'),
      '#description' => $this->t('The site key given to you when you <a href=":url">register for Friendly Captcha</a>.', [':url' => 'https://app.friendlycaptcha.com/account']),
      '#maxlength' => 64,
      '#required' => TRUE,
      '#title' => $this->t('Site key'),
      '#type' => 'textfield',
    ];

    $form['general']['friendlycaptcha_api_key'] = [
      '#default_value' => $config->get('api_key'),
      '#description' => $this->t('The API key given to you when you <a href=":url">register for Friendly Captcha</a>.', [':url' => 'https://www.google.com/friendlycaptcha/admin']),
      '#maxlength' => 128,
      '#required' => TRUE,
      '#title' => $this->t('API key'),
      '#type' => 'textfield',
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('friendlycaptcha.settings');
    $config
      ->set('site_key', $form_state->getValue('friendlycaptcha_site_key'))
      ->set('api_key', $form_state->getValue('friendlycaptcha_api_key'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
